// Copyright (C) 2010-2011 - Michael Baudin
// Copyright (C) 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

/* -------------------------------------------------------------------------- */
/* This gateway uses the new scilab api
/* -------------------------------------------------------------------------- */

#include "machine.h"
#include "Scierror.h"
#include "stack-c.h"
#include "api_scilab.h"
#include "localization.h"

#include "accsum.h"

// s = accsum_fdcs(x) 
// [s,e] = accsum_fdcs(x) 
// returns the sum of x, with a simply compensated summation.
int sci_accsum_fscs (char * fname) {

	SciErr sciErr;
	int *piAddr = NULL;
	int iType = 0;
	int rowsX,colsX;
	double* lX = NULL;
	int iComplex = 0;
	int i;
        double s;
        double e;

	int minlhs=1, minrhs=1, maxlhs=2, maxrhs=1;

	CheckRhs(minrhs,maxrhs) ;
	CheckLhs(minlhs,maxlhs) ;

	//
	// Read X
	//
	sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddr);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return 0;
	}
	sciErr = getVarType(pvApiCtx, piAddr, &iType);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return 0;
	}
	if ( iType != sci_matrix ) 
	{
		Scierror(999,_("%s: Wrong type for input argument #%d. Matrix expected.\n"),fname,1);
		return 0;
	}
	iComplex	= isVarComplex(pvApiCtx, piAddr);
	if ( iComplex == 1 ) 
	{
		Scierror(999,_("%s: Wrong content for input argument #%d. Real matrix expected.\n"),fname,1);
		return 0;
	}
	sciErr = getMatrixOfDouble(pvApiCtx, piAddr, &rowsX, &colsX, &lX);
	if(sciErr.iErr)
	{
		printError(&sciErr, 0);
		return 0;
	}
	//
	// Perform the sum
        accsum_fscs(lX, rowsX*colsX, &s, &e);

        //
        // Set LHS
        if ( Lhs>=1 )
        {
            //
            // Create s
            sciErr = createMatrixOfDouble(pvApiCtx,Rhs+1, 1, 1, &s);
            if(sciErr.iErr)
            {
                printError(&sciErr, 0);
                return 0;
            }
            LhsVar(1) = Rhs+1;
        } 
        if ( Lhs==2 )
        {
            //
            // Create e
            sciErr = createMatrixOfDouble(pvApiCtx,Rhs+2, 1, 1, &e);
            if(sciErr.iErr)
            {
                printError(&sciErr, 0);
                return 0;
            }
            LhsVar(2) = Rhs+2;
        }

	return(0);

}

